pub enum PathDialect {
Posix,
Windows,
}Expand description
Lexical path syntax used by a configuration value.
This is separate from the compiling host target so a portable configuration can validate a Windows overlay while it is read on Linux or macOS.
Variants
Implementations
Sourceimpl PathDialect
impl PathDialect